@@ -10,7 +10,7 @@ function(object, ...)
     cat("\n---------\n")
     cat("\nVariable:",colnames(object$dframe[i]))
     cat("\nLoadings:\n")
-    print(round(object$cat.loadings[[i]], 4))
+    print(round(object$loadings[[i]], 4))
     cat("\nCategory centroids:\n")
     print(round(object$cat.centroids[[i]], 4))
     cat("\nCategory quantifications (scores):\n")
